@@ -1,20 +1,20 @@
 F23Fun<-function(df,model,m_nf){
-  
+
   data<-sapply(df,as.character)
-  
-  dF23<-data[-1,which(data[1,]=="F23")];F23<-as.numeric(dF23[which(is.na(as.numeric(dF23))==FALSE)]);df<-as.data.frame(F23) 
-  
-  
+
+  dF23<-data[-1,which(data[1,]=="F23")];F23<-as.numeric(dF23[which(is.na(as.numeric(dF23))==FALSE)]);df<-as.data.frame(F23)
+
+
 
 ##################################################
 F3colname <- c("Model","Log_Max_likelihood_Value","AIC","mean[1]","mean[2]","mean[3]","mean[4]","mean[5]","mean[6]","mean[7]","mean[8]","mean[9]",
                "Var[1]","Var[2]","Var[3]","Var[4]","Var[5]","Var[6]","Var[7]","Var[8]","Var[9]","Proportion[1]","Proportion[2]","Proportion[3]","Proportion[4]","Proportion[5]","Proportion[6]",
-               "Proportion[7]","Proportion[8]","Proportion[9]","m","da(d)","db","ha(h)","hb","i","jab","jba","l","Major-Gene Var","Heritability(Major-Gene)(%)",	
+               "Proportion[7]","Proportion[8]","Proportion[9]","m","da(d)","db","ha(h)","hb","i","jab","jba","l","Major-Gene Var","Heritability(Major-Gene)(%)",
                "U1 square","P(U1 square)","U2 square","P(U2 square)","U3 square","P(U3 square)","nW square","P(nW square)","Dn","P(Dn)")
 
 F3ModelFun<-list(NA)
 ###################define each model function##################
-############################################0MG model#########################################  
+############################################0MG model#########################################
 F3ModelFun[[1]] <-function(K1,logL,df,m_nf){
   data <- as.matrix(as.numeric(df[,1]))
   m_sam <- dim(data)[1]; mean0 <- mean(data); sigma0 <- var(data)
@@ -42,14 +42,14 @@ F3ModelFun[[1]] <-function(K1,logL,df,m_nf){
   u<- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D<-as.numeric(ks.test(bmw,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(w),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("0MG",round(abc,4),round(AIC,4),round(m,4)," "," "," "," "," "," "," "," ",round(sigma,4)," "," "," "," "," "," "," "," ",round(mix_pi,4)," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," "," ",round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(w,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
   OUTPUT<-list(output)
   return(OUTPUT)
 }
-############################################1MG-AD model######################################### 
+############################################1MG-AD model#########################################
 F3ModelFun[[2]]  <-function(K1,logL,df,m_nf){
   data <- as.matrix(as.numeric(df[,1]))
   ##############procedure start####################
@@ -97,14 +97,14 @@ F3ModelFun[[2]]  <-function(K1,logL,df,m_nf){
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
-  AIC<--2*abc+2*4
+  AIC<--2*abc+2*5
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
-  ll <- jj/sigma0  
-  #########hypothesis testing##############  
+  ll <- jj/sigma0
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d2)
@@ -124,7 +124,7 @@ F3ModelFun[[2]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-AD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," ",round(B1[3],4)," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -138,8 +138,8 @@ F3ModelFun[[3]]  <-function(K1,logL,df,m_nf)
   ##############procedure start####################
   m_sam <- dim(data)[1]; d2 <- 3; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
-  ##########1MG-A(A-2)#####################  
-  a1 <- sqrt(sigma0/m_sam)
+  ##########1MG-A(A-2)#####################
+  a1 <- sqrt(sigma0)
   m <- as.matrix(c((mean0+2*a1),mean0,(mean0-2*a1)))
   mi <- as.matrix(c(0.25,0.5,0.25))
   sigma <- matrix((sigma0/2),3,1)
@@ -185,14 +185,14 @@ F3ModelFun[[3]]  <-function(K1,logL,df,m_nf)
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*3
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
-  ll <- jj/sigma0  
-  #########hypothesis testing##############  
+  ll <- jj/sigma0
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d2)
@@ -212,7 +212,7 @@ F3ModelFun[[3]]  <-function(K1,logL,df,m_nf)
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-A",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -231,7 +231,7 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
   mi <- as.matrix(c(0.25,0.5,0.25))
   sigma <- matrix((sigma0/2),3,1)
   L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
-  ##########iteration process###########
+    ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,3,m_sam); swx <- matrix(0,3,1);s0 <- matrix(0,2,1)
   while(stopa > m_esp && iteration <= 1000){
@@ -244,11 +244,11 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
     n0[abs(n0)<0.000001] <- 0.000001
     aa1<-3*sumwx[1]/n0[1]-4*sumwx[2]/n0[2]+sumwx[3]/n0[3]
     aa2<-9*sigma[1]/n0[1]+16*sigma[2]/n0[2]+sigma[3]/n0[3]
-    aa3<-aa1/aa2 
+    aa3<-aa1/aa2
     m[1]<-(sumwx[1]-sigma[1]*3*aa3)/n0[1]
     m[2]<-(sumwx[2]+sigma[2]*4*aa3)/n0[2]
     m[3]<-(sumwx[3]-sigma[3]*aa3)/n0[3]
-    ######first order genetic parameter process########## 
+    ######first order genetic parameter process##########
     hh1 <- matrix(c(1,1,1,1,0.5,-1),3,2)
     B1<-solve(crossprod(hh1,hh1))%*%crossprod(hh1,m)
     aa3<-0.75*B1[2]^2/m_nf
@@ -272,15 +272,15 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*4
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
-  ll <- jj/sigma0    
-  #########hypothesis testing##############  
-  data <- sort(data); 
+  ll <- jj/sigma0
+  #########hypothesis testing##############
+  data <- sort(data);
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d2)
   for(i in 1:d2){
@@ -299,20 +299,20 @@ F3ModelFun[[4]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-EAD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
   OUTPUT<-list(output,mi)
   return(OUTPUT)
-}  
+}
 ############################################1MG-NCD model#########################################
 F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
   data <- as.matrix(as.numeric(as.numeric(df[,1])))
   ##############procedure start####################
   m_sam <- dim(data)[1]; d2 <- 3; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
-  ##########1MG-NCD(A-4)#####################  
+  ##########1MG-NCD(A-4)#####################
   a1 <- sqrt(sigma0/m_sam)
   m <- as.matrix(c((mean0+2*a1),mean0,(mean0-2*a1)))
   mi <- as.matrix(c(0.25,0.5,0.25))
@@ -335,10 +335,10 @@ F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
     m[1]<-(sumwx[1]-sigma[1]*aa3)/n0[1]
     m[2]<-(sumwx[2]+sigma[2]*aa3*4.0)/n0[2]
     m[3]<-(sumwx[3]-sigma[3]*aa3*3.0)/n0[3]
-    ######first order genetic parameter process########## 
+    ######first order genetic parameter process##########
     hh1 <- matrix(c(1,1,1,1,-0.5,-1),3,2)
     B1<-solve(crossprod(hh1,hh1))%*%crossprod(hh1,m)
-    aa3<-0.75*B1[2]^2/m_nf 
+    aa3<-0.75*B1[2]^2/m_nf
     ##########obtain variance##########
     for(i in 1:d2) {  swx[i] <- WW[i,]%*%(data-m[i])^2 }
     s0[1]<-swx[1]+swx[3]
@@ -359,14 +359,14 @@ F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*4
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
-  ll <- jj/sigma0     
-  #########hypothesis testing##############  
+  ll <- jj/sigma0
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d2)
@@ -386,7 +386,7 @@ F3ModelFun[[5]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("1MG-NCD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," "," "," "," ",round(t(sigma),4)," "," "," "," "," "," ",round(t(mix_pi),4)," "," "," "," "," "," ",round(B1[1],4),round(B1[2],4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -399,13 +399,13 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
   ##############procedure start####################
   m_sam <- dim(data)[1]; d4 <- 9; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
-  #############2MG-ADI model(B-1)###########################  
-  a1 <- sqrt(sigma0/m_sam) 
+  #############2MG-ADI model(B-1)###########################
+  a1 <- sqrt(sigma0)
   sigma <- matrix((sigma0/2),9,1)
   m <- as.matrix(c((mean0+3.2*a1),(mean0+2.4*a1),(mean0+1.6*a1),(mean0+0.8*a1),mean0,
                    (mean0-0.8*a1),(mean0-1.6*a1),(mean0-2.4*a1),(mean0-3.2*a1)))
   mi <- as.matrix(c(0.0625,0.125,0.0625,0.125,0.25,0.125,0.0625,0.125,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))  
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,9,m_sam); swx <- matrix(0,9,1);g_a<-matrix(0,5,1);s0 <- matrix(0,2,1)
@@ -416,7 +416,7 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
     mix_pi <- as.matrix(rowSums(WW)/m_sam)
     sumwx <- WW%*%data
     n0 <- m_sam*mix_pi
-    n0[abs(n0)<0.000001] <- 0.000001  
+    n0[abs(n0)<0.000001] <- 0.000001
     m<-sumwx/n0
     hh5 <- matrix(c(1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,-1,-1,-1,1,0,-1,1,0,-1,1,0,-1,0,0,0,0.5,0.5,0.5,0,0,0,
                     0,0.5,0,0,0.5,0,0,0.5,0,1,0,-1,0,0,0,-1,0,1,0,0.5,0,0,0,0,0,-0.5,0,0,0,0,0.5,0,-0.5,0,
@@ -449,15 +449,15 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
-    if(iteration>15)break
+    if(stopa < 0) {stopa <- -stopa}
+    if(iteration>1000)break
   }
   abc<-L0
   AIC<--2*abc+2*10
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d4)
@@ -477,7 +477,7 @@ F3ModelFun[[6]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-ADI",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B5),4),round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -490,12 +490,12 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
   ##############procedure start####################
   m_sam <- dim(data)[1]; d4 <- 9; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
-  #########2MG-AD model(B-2)############# 
-  a1 <- sqrt(sigma0/m_sam) 
+  #########2MG-AD model(B-2)#############
+  a1 <- sqrt(sigma0)
   sigma <- matrix((sigma0/2),9,1)
   m <- as.matrix(c((mean0+3.2*a1),(mean0+2.4*a1),(mean0+1.6*a1),(mean0+0.8*a1),mean0,(mean0-0.8*a1),(mean0-1.6*a1),(mean0-2.4*a1),(mean0-3.2*a1)))
   mi <- as.matrix(c(0.0625,0.125,0.0625,0.125,0.25,0.125,0.0625,0.125,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi))) 
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,9,m_sam); swx <- matrix(0,9,1); hh <- matrix(0,4,4); b_line <- matrix(0,4,1)
@@ -547,7 +547,7 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
                      0,0,0,0.5,0.5,0.5,0,0,0,0,0.5,0,0,0.5,0,0,0.5,0),9,5)
     B61<-solve(crossprod(hh61,hh61))%*%crossprod(hh61,m)
     g_a[1]<-(0.5*B61[3]^2+0.25*B61[5]^2)/m_nf
-    g_a[2]<-(0.5*B61[2]^2+0.25*B61[4]^2)/m_nf 
+    g_a[2]<-(0.5*B61[2]^2+0.25*B61[4]^2)/m_nf
     g_a[3]<-(0.5*(B61[2]^2+B61[3]^2)+0.25*(B61[4]^2+B61[5]^2))/m_nf
     #######################obtain variance#######################################
     for(i in 1:d4) {  swx[i] <- WW[i,]%*%(data-m[i])^2 }
@@ -572,14 +572,14 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*6
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d4)
@@ -599,7 +599,7 @@ F3ModelFun[[7]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-AD",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B61),4)," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -613,11 +613,11 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
   m_sam <- dim(data)[1]; d4 <- 9; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
   ########2MG-A model(B-3)###############
-  a1 <- sqrt(sigma0/m_sam) 
+  a1 <- sqrt(sigma0)
   sigma <- matrix((sigma0/2),9,1)
   m <- as.matrix(c((mean0+3.2*a1),(mean0+2.4*a1),(mean0+1.6*a1),(mean0+0.8*a1),mean0,(mean0-0.8*a1),(mean0-1.6*a1),(mean0-2.4*a1),(mean0-3.2*a1)))
   mi <- as.matrix(c(0.0625,0.125,0.0625,0.125,0.25,0.125,0.0625,0.125,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi))) 
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,9,m_sam); swx <- matrix(0,9,1); hh <- matrix(0,6,6); b_line <- matrix(0,6,1)
@@ -663,8 +663,8 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
     b_line[1]<-sumwx[1]/n0[1]-sumwx[3]/n0[3]-sumwx[7]/n0[7]+sumwx[9]/n0[9]
     b_line[2]<-sumwx[1]/n0[1]-sumwx[2]/n0[2]-sumwx[7]/n0[7]+sumwx[8]/n0[8]
     b_line[3]<-sumwx[3]/n0[3]-2*sumwx[5]/n0[5]+sumwx[7]/n0[7]
-    b_line[4]<-2*sumwx[2]/n0[2]-2*sumwx[3]/n0[3]-sumwx[4]/n0[4]+sumwx[6]/n0[6]     
-    b_line[5]<-sumwx[7]/n0[7]-2*sumwx[8]/n0[8]+sumwx[9]/n0[9]     
+    b_line[4]<-2*sumwx[2]/n0[2]-2*sumwx[3]/n0[3]-sumwx[4]/n0[4]+sumwx[6]/n0[6]
+    b_line[5]<-sumwx[7]/n0[7]-2*sumwx[8]/n0[8]+sumwx[9]/n0[9]
     b_line[6]<-sumwx[1]/n0[1]-2*sumwx[4]/n0[4]+sumwx[7]/n0[7]
     B7<- solve(hh,b_line)
     ############################################################################
@@ -678,10 +678,10 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
     m[8]<-(sumwx[8]+sigma[8]*(-B7[2]+2*B7[5]))/n0[8]
     m[9]<-(sumwx[9]-sigma[9]*(B7[1]+B7[5]))/n0[9]
     #########first order genetic parameter process##########
-    hh71 <- matrix(c(1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,-1,-1,-1,1,0,-1,1,0,-1,1,0,-1),9,3) 
+    hh71 <- matrix(c(1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,-1,-1,-1,1,0,-1,1,0,-1,1,0,-1),9,3)
     B71<-solve(crossprod(hh71,hh71))%*%crossprod(hh71,m)
-    g_a[1]<-(0.5*B71[3]^2)/m_nf    
-    g_a[2]<-(0.5*B71[2]^2)/m_nf  
+    g_a[1]<-(0.5*B71[3]^2)/m_nf
+    g_a[2]<-(0.5*B71[2]^2)/m_nf
     g_a[3]<-g_a[1]+g_a[2]
     #######################obtain variance#######################################
     for(i in 1:d4) {  swx[i] <- WW[i,]%*%(data-m[i])^2 }
@@ -699,22 +699,22 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
       aa6<-abs(sigma[1]-aaa0)
       aaa0<-sigma[1]
       if(n_iter>20)break
-    }  
+    }
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2]
     sigma[5]<-sigma[1]+g_a[3];sigma[6]<-sigma[1]+g_a[2];sigma[8]<-sigma[1]+g_a[1]
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
-    if(iteration>15)break
+    if(stopa < 0) {stopa <- -stopa}
+    if(iteration>60)break
   }
   abc<-L0
   AIC<--2*abc+2*4
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d4)
@@ -734,8 +734,8 @@ F3ModelFun[[8]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
-  
+
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-A",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B71),4)," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -749,12 +749,12 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
   m_sam <- dim(data)[1]; d5 <- 6; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
   ##############2MG-EA model(B-4)#############################
-  a1 <- sqrt(sigma0/m_sam) 
+  a1 <- sqrt(sigma0)
   sigma <- matrix((sigma0/2),6,1)
   m <- as.matrix(c((mean0+3*a1),(mean0+2.4*a1),mean0,
                    (mean0+1.7*a1),(mean0-0.7*a1),(mean0-3*a1)))
   mi <- as.matrix(c(0.0625,0.25,0.125,0.25,0.25,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi))) 
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,6,m_sam); swx <- matrix(0,6,1); hh <- matrix(0,3,3); b_line <- matrix(0,3,1)
@@ -794,7 +794,7 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
     m[5]<-(sumwx[5]-sigma[5]*(B8[2]-2.0*B8[3]))/n0[5]
     m[6]<-(sumwx[6]-sigma[6]*B8[3])/n0[6]
     #########first order genetic parameter process##########
-    hh81 <- matrix(c(1,1,1,1,1,2,1,0,-1,-2),5,2) 
+    hh81 <- matrix(c(1,1,1,1,1,2,1,0,-1,-2),5,2)
     B81<-solve(crossprod(hh81,hh81))%*%crossprod(hh81,m[-4])
     g_a[1]<-0.5*B81[2]^2/m_nf
     g_a[2]<-B81[2]^2/m_nf
@@ -813,22 +813,22 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
       aa6<-abs(sigma[1]-aaa0)
       aaa0<-sigma[1]
       if(n_iter>20)break
-    }  
+    }
     sigma[6]<-sigma[1];sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[1]
     sigma[5]<-sigma[1]+g_a[1];sigma[3]<-sigma[1]+g_a[2]
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
-    if(iteration>15)break
+    if(stopa < 0) {stopa <- -stopa}
+    if(iteration>600)break
   }
   abc<-L0
   AIC<--2*abc+2*3
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
-  data <- sort(data); 
+  #########hypothesis testing##############
+  data <- sort(data);
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d5)
   for(i in 1:d5){
@@ -847,7 +847,7 @@ F3ModelFun[[9]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-EA",round(abc,4),round(AIC,4),round(t(m),4)," "," "," ",round(t(sigma),4)," "," "," ",round(t(mix_pi),4)," "," "," ",round(t(B81),4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
  output<-as.matrix(output)
@@ -861,11 +861,11 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
   m_sam <- dim(data)[1]; d4 <- 9; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
   ######2MG-CD model(B-5)#####################
-  a1 <- sqrt(sigma0/m_sam) 
+  a1 <- sqrt(sigma0)
   sigma <- matrix((sigma0/2),9,1)
   m <- as.matrix(c((mean0+3.2*a1),(mean0+2.4*a1),(mean0+1.6*a1),(mean0+0.8*a1),mean0,(mean0-0.8*a1),(mean0-1.6*a1),(mean0-2.4*a1),(mean0-3.2*a1)))
   mi <- as.matrix(c(0.0625,0.125,0.0625,0.125,0.25,0.125,0.0625,0.125,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi))) 
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,9,m_sam); swx <- matrix(0,9,1); hh <- matrix(0,6,6); b_line <- matrix(0,6,1)
@@ -926,7 +926,7 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
     m[8]<-(sumwx[8]+sigma[8]*(-B9[3]-B9[4]+B9[6]))/n0[8]
     m[9]<-(sumwx[9]-sigma[9]*B9[6])/n0[9]
     #########first order genetic parameter process##########
-    hh91 <- matrix(c(1,1,1,1,1,1,1,1,1,1,1,1,0.5,0.5,0.5,-1,-1,-1,1,0.5,-1,1,0.5,-1,1,0.5,-1),9,3) 
+    hh91 <- matrix(c(1,1,1,1,1,1,1,1,1,1,1,1,0.5,0.5,0.5,-1,-1,-1,1,0.5,-1,1,0.5,-1,1,0.5,-1),9,3)
     B91<-solve(crossprod(hh91,hh91))%*%crossprod(hh91,m)
     g_a[1]<-0.75*B91[3]^2/m_nf
     g_a[2]<-0.75*B91[2]^2/m_nf
@@ -946,21 +946,21 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
       aa6<-abs(sigma[1]-aaa0)
       aaa0<-sigma[1]
       if(n_iter>20)break
-    }  
+    }
     sigma[3]<-sigma[1];sigma[7]<-sigma[1];sigma[9]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[4]<-sigma[1]+g_a[2]
     sigma[5]<-sigma[1]+g_a[3];sigma[6]<-sigma[1]+g_a[2];sigma[8]<-sigma[1]+g_a[1]
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*4
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d4)
@@ -980,7 +980,7 @@ F3ModelFun[[10]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-CD",round(abc,4),round(AIC,4),round(t(m),4),round(t(sigma),4),round(t(mix_pi),4),round(t(B91),4)," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
   output<-as.matrix(output)
@@ -994,11 +994,11 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
   m_sam <- dim(data)[1]; d5 <- 6; m_esp <- 0.0001
   mean0 <- mean(data);sigma0 <- var(data)
   #########2MG-EAD model(B-6)#########################
-  a1 <- sqrt(sigma0/m_sam) 
+  a1 <- sqrt(sigma0/m_sam)
   sigma <- matrix((sigma0/2),6,1)
   m <- as.matrix(c((mean0+3*a1),(mean0+2.4*a1),(mean0+1.7*a1),mean0,(mean0-0.7*a1),(mean0-3*a1)))
   mi <- as.matrix(c(0.0625,0.25,0.25,0.125,0.25,0.0625))
-  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi))) 
+  L0 <- sum(log(dmixnorm(data,m,sqrt(sigma),mi)))
   ##########iteration process###########
   iteration <- 0; stopa <- 1000
   WW <- matrix(0,6,m_sam); swx <- matrix(0,6,1); hh <- matrix(0,4,4); b_line <- matrix(0,4,1)
@@ -1043,7 +1043,7 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
     m[5]<-(sumwx[5]-sigma[5]*B10[3])/n0[5]
     m[6]<-(sumwx[6]-sigma[6]*(B10[2]+B10[4]))/n0[6]
     #########first order genetic parameter process##########
-    hh101 <- matrix(c(1,1,1,1,1,1,2,1.5,1,0,-0.5,-2),6,2) 
+    hh101 <- matrix(c(1,1,1,1,1,1,2,1.5,1,0,-0.5,-2),6,2)
     B101<-solve(crossprod(hh101,hh101))%*%crossprod(hh101,m)
     g_a[1]<-0.75*B101[2]^2/m_nf
     g_a[2]<-1.5*B101[2]^2/m_nf
@@ -1061,21 +1061,21 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
       aa6<-abs(sigma[1]-aaa0)
       aaa0<-sigma[1]
       if(n_iter>20)break
-    }  
+    }
     sigma[4]<-sigma[1];sigma[6]<-sigma[1]
     sigma[2]<-sigma[1]+g_a[1];sigma[5]<-sigma[1]+g_a[1]
     sigma[3]<-sigma[1]+g_a[2]
     L1 <- sum(log(dmixnorm(data,m,sqrt(sigma),mix_pi)))
     stopa <- L1 - L0
     L0 <- L1
-    if(stopa < 0) {stopa <- -stopa} 
+    if(stopa < 0) {stopa <- -stopa}
   }
   abc<-L0
   AIC<--2*abc+2*3
   jj <- sigma0 - sigma[1]
   if(jj < 0) {jj <- 0}
   ll <- jj/sigma0
-  #########hypothesis testing##############  
+  #########hypothesis testing##############
   data <- sort(data)
   w1<-1/(12*m_sam)
   bmw <- matrix(0,m_sam,1); bmwsl <- matrix(0,m_sam,d5)
@@ -1095,7 +1095,7 @@ F3ModelFun[[11]]  <-function(K1,logL,df,m_nf){
   u <- as.matrix(c(12*m_sam*((dd[1]/m_sam-0.5)^2),((45*m_sam)/4)*((dd[2]/m_sam-1/3)^2),180*m_sam*((dd[3]/m_sam-1/12)^2)))
   D <- as.numeric(ks.test(P2,"punif")[[1]][1])
   tt <- as.matrix(c((1 - pchisq(u[1],1)),(1 - pchisq(u[2],1)),(1 - pchisq(u[3],1)),K1(WW2),(1-pkolm(D,m_sam))))
-  
+
   tt[which(tt>=10e-4)]<-round(tt[which(tt>=10e-4)],4);tt[which(tt<10e-4)]<-format(tt[which(tt<10e-4)],scientific=TRUE,digit=4)
   output <- data.frame("2MG-EAD",round(abc,4),round(AIC,4),round(t(m),4)," "," "," ",round(t(sigma),4)," "," "," ",round(t(mix_pi),4)," "," "," ",round(t(B101),4)," "," "," "," "," "," "," ",round(jj,4),round(ll*100,4),round(u[1],4),tt[1],round(u[2],4),tt[2],round(u[3],4),tt[3],round(WW2,4),tt[4],round(D,4),tt[5])
   output<-as.matrix(output)
@@ -1113,9 +1113,9 @@ K1F23 <- function(x){
   V0 <- V0 + (gamma(j+0.5)*sqrt(4*j+1)/(gamma(0.5)*gamma(j+1)))*exp(-(4*j+1)^2/(16*x))*(I1-I2)}
   V <- (1/sqrt(2*x))*V0
   return (1-V)
-} 
+}
 
-logLF23 <- function(nm,nng,mi,mn,s,d1) { sum2 <- sum(log(dmixnorm(d1,mn,sqrt(s),mi)));return (sum2) } 
+logLF23 <- function(nm,nng,mi,mn,s,d1) { sum2 <- sum(log(dmixnorm(d1,mn,sqrt(s),mi)));return (sum2) }
 
 
 if(model=="All models"){
@@ -1144,10 +1144,10 @@ if(model=="All models"){
                      "1MG-EAD"=F3ModelFun[[4]](K1F23,logLF23,df,m_nf),"1MG-NCD"=F3ModelFun[[5]](K1F23,logLF23,df,m_nf),"2MG-ADI"=F3ModelFun[[6]](K1F23,logLF23,df,m_nf),
                      "2MG-AD"=F3ModelFun[[7]](K1F23,logLF23,df,m_nf),"2MG-A"=F3ModelFun[[8]](K1F23,logLF23,df,m_nf),"2MG-EA"=F3ModelFun[[9]](K1F23,logLF23,df,m_nf),
                      "2MG-CD"=F3ModelFun[[10]](K1F23,logLF23,df,m_nf),"2MG-EAD"=F3ModelFun[[11]](K1F23,logLF23,df,m_nf))
-  
+
   allresult<-allresultq[[1]]
   if(model!="0MG"){
-    mi<-allresultq[[2]]  
+    mi<-allresultq[[2]]
   }else{
     mi<-NULL
   }
